@@ -8,14 +8,18 @@ class JSONFormField(fields.Field):
 
     def __init__(self, *args, **kwargs):
         self.simple = kwargs.pop('simple', False)
-        self.encoder_kwargs = kwargs.pop('encoder_kwargs')
-        self.decoder_kwargs = kwargs.pop('decoder_kwargs')
+        self.encoder_kwargs = kwargs.pop('encoder_kwargs', {})
+        self.decoder_kwargs = kwargs.pop('decoder_kwargs', {})
         super(JSONFormField, self).__init__(*args, **kwargs)
 
     def clean(self, value):
         # Have to jump through a few hoops to make this reliable
         value = super(JSONFormField, self).clean(value)
 
+        # allow an empty value on an optional field
+        if value is None:
+            return value
+
         ## Got to get rid of newlines for validation to work
         # Data newlines are escaped so this is safe
         value = value.replace('\r', '').replace('\n', '')
